@@ -1,5 +1,8 @@
 use crate::{
-    config::{CompiledPaths, GlobalPassOption, JsMinifyOptions, JscTarget, ModuleConfig},
+    config::{
+        util::BoolOrObject, CompiledPaths, GlobalPassOption, JsMinifyOptions, JscTarget,
+        ModuleConfig,
+    },
     SwcComments,
 };
 use compat::es2020::export_namespace_from;
@@ -14,8 +17,9 @@ use swc_ecma_ast::{EsVersion, Module};
 use swc_ecma_minifier::option::MinifyOptions;
 use swc_ecma_parser::Syntax;
 use swc_ecma_transforms::{
-    compat, fixer, helpers, hygiene, hygiene::hygiene_with_config, modules, modules::util::Scope,
-    optimization::const_modules, pass::Optional, proposals::private_in_object,
+    compat, compat::es2022::private_in_object, fixer, helpers, hygiene,
+    hygiene::hygiene_with_config, modules, modules::util::Scope, optimization::const_modules,
+    pass::Optional,
 };
 use swc_ecma_visit::{as_folder, noop_visit_mut_type, VisitMut};
 
@@ -219,6 +223,15 @@ impl<'a, 'b, P: swc_ecma_visit::Fold> PassBuilder<'a, 'b, P> {
             ))
         };
 
+        let is_mangler_enabled = self
+            .minify
+            .as_ref()
+            .map(|v| match v.mangle {
+                BoolOrObject::Bool(true) | BoolOrObject::Obj(_) => true,
+                _ => false,
+            })
+            .unwrap_or(false);
+
         let module_scope = Rc::new(RefCell::new(Scope::default()));
         chain!(
             self.pass,
@@ -249,7 +262,7 @@ impl<'a, 'b, P: swc_ecma_visit::Fold> PassBuilder<'a, 'b, P> {
             }),
             Optional::new(
                 hygiene_with_config(self.hygiene.clone().unwrap_or_default()),
-                self.hygiene.is_some()
+                self.hygiene.is_some() && !is_mangler_enabled
             ),
             Optional::new(fixer(comments.map(|v| v as &dyn Comments)), self.fixer),
         )
